@@ -3,27 +3,25 @@ package Test::Mojo::Role::Debug;
 use Mojo::Base -base;
 use Role::Tiny;
 use Carp qw/croak/;
+use Test::More ();
 
-our $VERSION = '1.001001'; # VERSION
+our $VERSION = '1.002001'; # VERSION
 
 sub d {
     my ( $self, $selector ) = @_;
+    return $self if $self->success;
 
     my $markup = length $selector
         ? $self->tx->res->dom->at($selector)
         : $self->tx->res->dom;
 
     unless ( length $markup ) {
-        warn "\nDEBUG DUMPER: the selector ($selector) you provided "
+        Test::More::diag "\nDEBUG DUMPER: the selector ($selector) you provided "
             . "did not match any elements\n\n";
         return $self;
     }
 
-# use Acme::Dump::And::Dumper;
-        $Data::Dumper::Useqq=1;
-        # warn DnD [ "\nDEBUG DUMPER: the selector ($selector) you provided "
-            # . "did not match any elements\n\n" ];
-    warn "\nDEBUG DUMPER:\n$markup\n\n";
+    Test::More::diag "\nDEBUG DUMPER:\n$markup\n\n";
 
     return $self;
 }
@@ -53,8 +51,11 @@ Test::Mojo::Role::Debug - Test::Mojo role to make debugging test failures easier
     my $t = Test::Mojo::WithRoles->new('MyApp');
 
     $t->get_ok('/')->status_is(200)
-        ->d         # Dump entire DOM
-        ->d('#foo') # Dump a specific element
+        ->element_exists('existant')
+        ->d         # Does nothing, since test succeeded
+        ->element_exists('non_existant')
+        ->d         # Dump entire DOM on fail
+        ->d('#foo') # Dump a specific element on fail
     ;
 
     done_testing;
@@ -73,11 +74,12 @@ You have all the methods provided by L<Test::Mojo>, plus these:
 
 =head2 C<d>
 
-    $t->d;         # print entire DOM
-    $t->d('#foo'); # print a specific element
+    $t->d;         # print entire DOM on failure
+    $t->d('#foo'); # print a specific element on failure
 
 B<Returns> its invocant.
-Dumps the DOM of the current page to the screen. B<Takes> an optional
+On failure of previous tests (see L<Mojo::DOM/"success">),
+dumps the DOM of the current page to the screen. B<Takes> an optional
 selector to be passed to L<Mojo::DOM/"at">, in which case, only
 the markup of that element will be dumped.
 
@@ -116,6 +118,14 @@ to C<bug-test-mojo-role-debug at rt.cpan.org>
 
 =for html  </div></div>
 
+=head1 CONTRIBUTORS
+
+=for html  <div style="display: table; height: 91px; background: url(http://zoffix.com/CPAN/Dist-Zilla-Plugin-Pod-Spiffy/icons/section-contributors.png) no-repeat left; padding-left: 120px;" ><div style="display: table-cell; vertical-align: middle;">
+
+=for html   <span style="display: inline-block; text-align: center;"> <a href="http://metacpan.org/author/JBERGER"> <img src="http://www.gravatar.com/avatar/cc767569f5863a7c261991ee5b23f147?d=http%3A%2F%2Fwww.gravatar.com%2Favatar%2F28d0d015d88863cd15e9fd69e0885fc0" alt="JBERGER" style="display: block; margin: 0 3px 5px 0!important; border: 1px solid #666; border-radius: 3px; "> <span style="color: #333; font-weight: bold;">JBERGER</span> </a> </span>
+
+=for html  </div></div>
+
 =head1 LICENSE
 
 You can use and distribute this module under the same terms as Perl itself.
